==> ToolChain_STM32_1.0.42.tar.bz: ToolChain_STM32_1.0.42/CommonLibraries/extensions.c <==
/*{ extensions.c *********************************************************
 *
 *               ToolChain_STM32
 *
 * This code manages activated source-code extensions
 * written 2010-2012 by Gregor Rebel
 *
 * Basic framework template for
 *   - Olimex STM32-P107/ STM32-H107/ STM32-LCD eval board
 *   - StdPeripheralsLibrary CMSIS V3.4.0 (tested)
 *   - GNU toolchain from CodeSourcery G++
 *   - FreeRTOS v7.0.1
 *   - FixPointLib 
 *   - uIP TCP/IP-Stack
 *   - Color LCD Panel 320x240
 *   - local/ remote debugging (JTAG-Adapter may be connected to different computer)
 *
 * Coding-style
 *  + gnu99
 *    It's year 2012, get a decent compiler if your's does not comply with this.
 *    arm-none-eabi-gcc-4.4.1 does support gnu99.
 *     
 *  + Text Folding
 *    This source makes use of text folding to improve hierarchical readability 
 *    It has been written with jEdit + plugin Configurable Fold Handler.
 *    Activate folding in your favourite text-editor for { and } 
 *    (fold-start and -end) for best visual experience.
 *
}*/
//{ Includes *************************************************************

#include "extensions.h"

//} Includes
//{ Global Variables *****************************************************

    struct FirstTaskArguments TaskArguments;

//} Global Variables
//{ Function definitions *************************************************

void vApplicationMallocFailedHook(void) {
    /* Called if a call to pvPortMalloc() fails because there is insufficient
       free memory available in the FreeRTOS heap.  pvPortMalloc() is called
       internally by FreeRTOS API functions that create tasks, queues, software
       timers, and semaphores.  The size of the FreeRTOS heap is set by the
       configTOTAL_HEAP_SIZE configuration constant in FreeRTOSConfig.h. */
    Assert(0, ec_Malloc);
}
void vApplicationStackOverflowHook( xTaskHandle pxTask, signed char *pcTaskName ) {
    ( void ) pcTaskName;
    ( void ) pxTask;

    /* Run time stack overflow checking is performed if
       configconfigCHECK_FOR_STACK_OVERFLOW is defined to 1 or 2.  This hook
       function is called if a stack overflow is detected. */
    Assert(0, ec_None);
}
void startExtensions(void(*MainTask)(void*), size_t StackSize, void* MainArgument) {

    SystemInit();
    
    TaskArguments.MainTask    =(void*) MainTask;
    TaskArguments.MainArgument=MainArgument;
    
    xTaskCreate(firstTask,                         // function to start as thread
                (const signed char*) NULL,         // thread name (just for debugging)
                StackSize,                         // stack size
                &TaskArguments,                    // passed as argument to firstTask()
                (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                // can return a handle to created task
               );
    
    vTaskStartScheduler(); // FreeRTOS-scheduler (never returns)
    
    while (1);
}
       void firstTask(void *pvParameters) {

    struct FirstTaskArguments* Arguments=(struct FirstTaskArguments*) pvParameters;

#ifdef EXTENSION_600_example_usart
    example_usart_start();
#endif
#ifdef EXTENSION_600_example_threading_queues
    threading_start();
#endif
#ifdef EXTENSION_600_example_threading_semaphores
    threading_start();  
#endif
#ifdef EXTENSION_600_example_leds
    leds_start();
#endif

#ifdef EXTENSION_600_example_lcd_printf
    lcd_start_printf();
#endif

#ifdef EXTENSION_600_example_lcd_boxes
    lcd_start_boxes();
#endif

#ifdef EXTENSION_600_example_spi_master
    example_spi_start();
#endif

#ifdef EXTENSION_600_example_spi_slave
    example_spi_start();
#endif

#ifdef EXTENSION_http_server

#endif

    if (Arguments->MainTask != NULL) {
      void(*MainTask)(void*)=Arguments->MainTask;
      MainTask(Arguments->MainArgument);
    }
    while (1) mSleep(1000);
}

//} Function definitions

==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/CommonLibraries/extensions.c <==
/*{ extensions.c *********************************************************
 *
 *               ToolChain_STM32
 *
 * This code manages activated source-code extensions
 * written 2010-2012 by Gregor Rebel
 *
 * Basic framework template for
 *   - Olimex STM32-P107/ STM32-H107/ STM32-LCD eval board
 *   - StdPeripheralsLibrary CMSIS V3.4.0 (tested)
 *   - GNU toolchain from CodeSourcery G++
 *   - FreeRTOS v7.0.1
 *   - FixPointLib 
 *   - uIP TCP/IP-Stack
 *   - Color LCD Panel 320x240
 *   - local/ remote debugging (JTAG-Adapter may be connected to different computer)
 *
 * Coding-style
 *  + gnu99
 *    It's year 2012, get a decent compiler if your's does not comply with this.
 *    arm-none-eabi-gcc-4.4.1 does support gnu99.
 *     
 *  + Text Folding
 *    This source makes use of text folding to improve hierarchical readability 
 *    It has been written with jEdit + plugin Configurable Fold Handler.
 *    Activate folding in your favourite text-editor for { and } 
 *    (fold-start and -end) for best visual experience.
 *
}*/
//{ Includes *************************************************************

#include "extensions.h"

//} Includes
//{ Global Variables *****************************************************

    struct FirstTaskArguments TaskArguments;

//} Global Variables
//{ Function definitions *************************************************

void vApplicationMallocFailedHook(void) {
    /* Called if a call to pvPortMalloc() fails because there is insufficient
       free memory available in the FreeRTOS heap.  pvPortMalloc() is called
       internally by FreeRTOS API functions that create tasks, queues, software
       timers, and semaphores.  The size of the FreeRTOS heap is set by the
       configTOTAL_HEAP_SIZE configuration constant in FreeRTOSConfig.h. */
    Assert(0, ec_Malloc);
}
void vApplicationStackOverflowHook( xTaskHandle pxTask, signed char *pcTaskName ) {
    ( void ) pcTaskName;
    ( void ) pxTask;

    /* Run time stack overflow checking is performed if
       configconfigCHECK_FOR_STACK_OVERFLOW is defined to 1 or 2.  This hook
       function is called if a stack overflow is detected. */
    Assert(0, ec_None);
}
void startExtensions(void(*MainTask)(void*), size_t StackSize, void* MainArgument) {

    SystemInit();
    
    TaskArguments.MainTask    =(void*) MainTask;
    TaskArguments.MainArgument=MainArgument;
    
    ttc_task_create(firstTask,                         // function to start as thread
                (const signed char*) NULL,         // thread name (just for debugging)
                StackSize,                         // stack size
                &TaskArguments,                    // passed as argument to firstTask()
                (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                // can return a handle to created task
               );
    
    vTaskStartScheduler(); // FreeRTOS-scheduler (never returns)
    
    while (1);
}
       void firstTask(void *pvParameters) {

    struct FirstTaskArguments* Arguments=(struct FirstTaskArguments*) pvParameters;

#ifdef EXTENSION_600_example_usart
    example_usart_start();
#endif
#ifdef EXTENSION_600_example_threading_queues
    threading_start();
#endif
#ifdef EXTENSION_600_example_threading_semaphores
    threading_start();  
#endif
#ifdef EXTENSION_600_example_leds
    leds_start();
#endif

#ifdef EXTENSION_600_example_lcd_printf
    lcd_start_printf();
#endif

#ifdef EXTENSION_600_example_lcd_boxes
    lcd_start_boxes();
#endif

#if defined(EXTENSION_600_example_spi_slave) || defined(EXTENSION_600_example_spi_master)
    example_spi_start();
#endif

#if defined(EXTENSION_600_example_i2c_master) || defined(EXTENSION_600_example_i2c_slave)
    example_i2c_start();
#endif

#ifdef EXTENSION_http_server

#endif

    if (Arguments->MainTask != NULL) {
      void(*MainTask)(void*)=Arguments->MainTask;
      MainTask(Arguments->MainArgument);
    }
    while (1) mSleep(1000);
}

//} Function definitions
